@@ -5,8 +5,8 @@
 ;; Author:   Dmitry Gutov <dmitry@gutov.dev>
 ;; URL:      https://github.com/dgutov/diff-hl
 ;; Keywords: vc, diff
-;; Package-Version: 20251216.242
-;; Package-Revision: e79aa49ad3cb
+;; Package-Version: 20260208.227
+;; Package-Revision: 3eefe6894193
 ;; Package-Requires: ((cl-lib "0.2") (emacs "26.1"))
 
 ;; This file is part of GNU Emacs.
@@ -316,10 +316,13 @@ It can be a relative expression as well, such as \"HEAD^\" with Git, or
                     (expt text-scale-mode-step text-scale-mode-amount)
                   1))
          (spacing (or (and (display-graphic-p) (default-value 'line-spacing)) 0))
+         (total-spacing (pcase spacing
+                          ((pred numberp) spacing)
+                          (`(,above . ,below) (+ above below))))
          (h (+ (ceiling (* (frame-char-height) scale))
-               (if (floatp spacing)
-                   (truncate (* (frame-char-height) spacing))
-                 spacing)))
+               (if (floatp total-spacing)
+                   (truncate (* (frame-char-height) total-spacing))
+                 total-spacing)))
          (w (min (frame-parameter nil (intern (format "%s-fringe" diff-hl-side)))
                  diff-hl-bmp-max-width))
          (_ (when (zerop w) (setq w diff-hl-bmp-max-width)))
